==> vue-index-bar-2.8.0.tgz: package/lib/mobile.js <==
import { defineComponent, props, setup as _setup } from "@xmweb-ui/vue-common";
import { renderless, api } from "@xmweb-ui/vue-renderless/index-bar/vue";
import "@xmweb-ui/vue-theme-mobile/index-bar/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["select", "change"],
  props: [].concat(props, ["indexList"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "xm-mobile-index-bar",
    on: {
      "scroll": _vm.handleScroll
    }
  }, [_c("div", {
    ref: "indexBarContent"
  }, [_vm._t("default")], 2), _c("div", {
    ref: "indexSide",
    staticClass: "xm-mobile-index-bar__side",
    on: {
      "mousedown": _vm.handleTouchDown,
      "mousemove": _vm.handleTouchMove,
      "mouseup": _vm.handleTouchUp,
      "touchstart": _vm.handleTouchDown,
      "touchmove": _vm.handleTouchMove,
      "touchend": _vm.handleTouchUp
    }
  }, _vm._l(_vm.indexList, function(label, index) {
    return _c("span", {
      key: label,
      class: ["xm-mobile-index-bar__label", _vm.state.index === index ? "xm-mobile-index-bar__label--active" : null],
      attrs: {
        "id": index
      },
      on: {
        "click": function click($event) {
          return _vm.handleIndexClick({
            index,
            label
          });
        }
      }
    }, [_vm._v(" " + _vm._s(label) + " ")]);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-index-bar-2.21.0.tgz: package/lib/mobile.js <==
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/index-bar/vue';
import '@opentinyvue/vue-theme-mobile/index-bar/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["select", "change"],
  props: [].concat(props, ["indexList"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-index-bar",
    on: {
      "scroll": _vm.handleScroll
    }
  }, [_c("div", {
    ref: "indexBarContent"
  }, [_vm._t("default")], 2), _c("div", {
    ref: "indexSide",
    staticClass: "tiny-mobile-index-bar__side",
    on: {
      "mousedown": _vm.handleTouchDown,
      "mousemove": _vm.handleTouchMove,
      "mouseup": _vm.handleTouchUp,
      "touchstart": _vm.handleTouchDown,
      "touchmove": _vm.handleTouchMove,
      "touchend": _vm.handleTouchUp
    }
  }, _vm._l(_vm.indexList, function(label, index) {
    return _c("span", {
      key: label,
      class: ["tiny-mobile-index-bar__label", _vm.state.index === index ? "tiny-mobile-index-bar__label--active" : null],
      attrs: {
        "id": index
      },
      on: {
        "click": function click($event) {
          return _vm.handleIndexClick({
            index,
            label
          });
        }
      }
    }, [_vm._v(" " + _vm._s(label) + " ")]);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
